@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http-client-tls
-version: 0.2.2
-id: http-client-tls-0.2.2-05f6aae0a8612df864dc61b6b7405a00
-key: httpc_7JsMjd7ibPl5y3iUkflPWF
+version: 0.2.3
+id: http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
+key: httpc_9zz2bALDbZz8lfJjVB5QvI
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/snoyberg/http-client
@@ -16,18 +16,18 @@ exposed: True
 exposed-modules:
     Network.HTTP.Client.TLS
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
-library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.2
-data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.2
-hs-libraries: HShttp-client-tls-0.2.2-7JsMjd7ibPl5y3iUkflPWF
+import-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/http-client-tls-0.2.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/http-client-tls-0.2.3
+hs-libraries: HShttp-client-tls-0.2.3-9zz2bALDbZz8lfJjVB5QvI
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    connection-0.2.5-8679766890f442068d557b54b4535c5d
+    connection-0.2.5-b1d9e33e03618093afb3c4e9d40c147e
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
-    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
+    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    tls-1.3.4-c1ffd726a31a364e53d7dbf7360c4f21
+    tls-1.3.5-cc53341e73a1ad5e4154c36129b6c569
 haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
 haddock-html: /usr/share/doc/haskell-http-client-tls/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
